@@ -19,7 +19,7 @@ class ExecutionResult:
     #: Message for the associated result.
     message: str = None
 
-    def echo(self) -> 'ExecutionResult':
+    def echo(self) -> "ExecutionResult":
         """Echoes the result if set for display to the console."""
-        print(f'[{self.code}] {self.message}')
+        print(f"[{self.code}] {self.message}")
         return self
